tiled.structures.array.ArrayMacroStructure
==========================================

.. currentmodule:: tiled.structures.array

.. autoclass:: ArrayMacroStructure

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ArrayMacroStructure.__init__
      ~ArrayMacroStructure.from_json
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~ArrayMacroStructure.dims
      ~ArrayMacroStructure.resizable
   
   